@@ -25,12 +25,9 @@
 #include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QImageReader>
-#include <QLabel>
 #include <QLayout>
-#include <QDoubleSpinBox>
 #include <QPointer>
 #include <QString>
-#include <QSignalMapper>
 #include <QCoreApplication>
 
 #include <kiconloader.h>
@@ -81,24 +78,28 @@ bool UploadDialogPrivate::init(const QString &configfile)
     atticaHelper = new KNSCore::AtticaHelper(q);
 
     bool success = true;
-    KConfig conf(configfile);
-    if (conf.accessMode() == KConfig::NoAccess) {
-        qCritical() << "No knsrc file named '" << configfile << "' was found." << endl;
-        success = false;
+    QFileInfo fi(configfile);
+    if (!fi.exists()) {
+        if (!fi.isAbsolute())
+            fi.setFile(QStandardPaths::locate(QStandardPaths::GenericConfigLocation, configfile));
+        if (!fi.exists()) {
+            qCCritical(KNEWSTUFF) << "No knsrc file named '" << fi.absoluteFilePath() << "' was found.";
+            success = false;
+        }
     }
-    // KConfig does not actually tell us whether the config file exists, so
-    // we check ourselves for better error messages.
-    if (QStandardPaths::locate(QStandardPaths::GenericConfigLocation, configfile).isEmpty()) {
-        qCritical() << "No knsrc file named '" << configfile << "' was found." << endl;
+
+    KConfig conf(fi.absoluteFilePath());
+    if (conf.accessMode() == KConfig::NoAccess) {
+        qCCritical(KNEWSTUFF) << "Knsrc file named '" << fi.absoluteFilePath() << "' could not be accessed.";
         success = false;
     }
 
     KConfigGroup group;
     if (conf.hasGroup("KNewStuff3")) {
-        qCDebug(KNEWSTUFF) << "Loading KNewStuff3 config: " << configfile;
+        qCDebug(KNEWSTUFF) << "Loading KNewStuff3 config: " << fi.absoluteFilePath();
         group = conf.group("KNewStuff3");
     } else {
-        qCritical() << "A knsrc file was found but it doesn't contain a KNewStuff3 section." << endl;
+        qCCritical(KNEWSTUFF) << "A knsrc file was found but it doesn't contain a KNewStuff3 section.";
         success = false;
     }
 
@@ -345,7 +346,7 @@ void UploadDialogPrivate::_k_checkCredentialsFinished(bool success)
 void UploadDialogPrivate::_k_licensesLoaded(const Attica::License::List &licenses)
 {
     ui.mLicenseCombo->clear();
-    foreach (const Attica::License &license, licenses) {
+    for (const Attica::License &license : licenses) {
         ui.mLicenseCombo->addItem(license.name(), license.id());
     }
 }
@@ -359,7 +360,7 @@ void UploadDialogPrivate::_k_contentByCurrentUserLoaded(const Attica::Content::L
 {
     setIdle(i18n("Fetching your previously updated content finished."));
 
-    foreach (const Attica::Content &content, contentList) {
+    for (const Attica::Content &content : contentList) {
         QListWidgetItem *contentItem = new QListWidgetItem(content.name());
         contentItem->setData(Qt::UserRole, content.id());
         ui.userContentList->addItem(contentItem);
@@ -383,7 +384,7 @@ void UploadDialogPrivate::_k_updatedContentFetched(const Attica::Content &conten
     ui.mSummaryEdit->setText(content.description());
     ui.mVersionEdit->setText(content.version());
     ui.changelog->setText(content.changelog());
-    ui.priceCheckBox->setChecked(content.attribute(QStringLiteral("downloadbuy1")) == QLatin1String("1"));
+    ui.priceCheckBox->setChecked(content.attribute(QStringLiteral("downloadbuy1")) == QLatin1Char('1'));
     ui.priceSpinBox->setValue(content.attribute(QStringLiteral("downloadbuyprice1")).toDouble());
     ui.priceReasonLineEdit->setText(content.attribute(QStringLiteral("downloadbuyreason1")));
 
@@ -550,7 +551,7 @@ void UploadDialog::setPreviewImageFile(uint number, const QUrl &file)
         d->ui.previewImage3->setPixmap(preview.scaled(d->ui.previewImage3->size()));
         break;
     default :
-        qCritical() << "Wrong preview image file number";
+        qCCritical(KNEWSTUFF) << "Wrong preview image file number";
         break;
     }
 }
@@ -565,17 +566,17 @@ void UploadDialogPrivate::_k_categoriesLoaded(const Attica::Category::List &load
     categories = loadedCategories;
 
     // at least one category is needed
-    if (categories.count() == 0) {
+    if (categories.isEmpty()) {
         KMessageBox::error(q,
                            i18np("The server does not recognize the category %2 to which you are trying to upload.",
                                  "The server does not recognize any of the categories to which you are trying to upload: %2",
-                                 categoryNames.size(), categoryNames.join(", ")),
+                                 categoryNames.size(), categoryNames.join(QLatin1String(", "))),
                            i18n("Error"));
         // close the dialog
         q->reject();
         return;
     }
-    foreach (const Attica::Category &c, categories) {
+    for (const Attica::Category &c : qAsConst(categories)) {
         ui.mCategoryCombo->addItem(c.name(), c.id());
     }
     atticaHelper->loadContentByCurrentUser();
@@ -643,7 +644,7 @@ void UploadDialogPrivate::_k_startUpload()
     //content.addAttribute("homepage1", ui.homepage->text());
     //content.addAttribute("blog1", ui.blog->text());
 
-    content.addAttribute(QStringLiteral("downloadbuy1"), ui.priceCheckBox->isChecked() ? "1" : "0");
+    content.addAttribute(QStringLiteral("downloadbuy1"), ui.priceCheckBox->isChecked() ? QStringLiteral("1") : QStringLiteral("0"));
     content.addAttribute(QStringLiteral("downloadbuyprice1"), QString::number(ui.priceSpinBox->value()));
     content.addAttribute(QStringLiteral("downloadbuyreason1"), ui.priceReasonLineEdit->text());
 
@@ -778,13 +779,13 @@ void UploadDialogPrivate::doUpload(const QString &index, const QUrl &path)
     if (index.isEmpty()) {
         job = currentProvider().setDownloadFile(contentId, fileName, fileContents);
         q->connect(job, SIGNAL(finished(Attica::BaseJob*)), q, SLOT(_k_fileUploadFinished(Attica::BaseJob*)));
-    } else if (index == QLatin1String("1")) {
+    } else if (index == QLatin1Char('1')) {
         job = currentProvider().setPreviewImage(contentId, index, fileName, fileContents);
         q->connect(job, SIGNAL(finished(Attica::BaseJob*)), q, SLOT(_k_preview1UploadFinished(Attica::BaseJob*)));
-    } else if (index == QLatin1String("2")) {
+    } else if (index == QLatin1Char('2')) {
         job = currentProvider().setPreviewImage(contentId, index, fileName, fileContents);
         q->connect(job, SIGNAL(finished(Attica::BaseJob*)), q, SLOT(_k_preview2UploadFinished(Attica::BaseJob*)));
-    } else if (index == QLatin1String("3")) {
+    } else if (index == QLatin1Char('3')) {
         job = currentProvider().setPreviewImage(contentId, index, fileName, fileContents);
         q->connect(job, SIGNAL(finished(Attica::BaseJob*)), q, SLOT(_k_preview3UploadFinished(Attica::BaseJob*)));
     }
@@ -845,9 +846,10 @@ void UploadDialogPrivate::_k_detailsLinkLoaded(const QUrl &url)
 QStringList UploadDialogPrivate::_supportedMimeTypes() const
 {
     QStringList mimeTypes;
-    QList<QByteArray> supported = QImageReader::supportedMimeTypes();
-    foreach (const QByteArray &mimeType, supported) {
-        mimeTypes.append(QString(mimeType));
+    const QList<QByteArray> supported = QImageReader::supportedMimeTypes();
+    mimeTypes.reserve(supported.count());
+    for (const QByteArray &mimeType : supported) {
+        mimeTypes.append(QString::fromLatin1(mimeType));
     }
     return mimeTypes;
 }
